==> kui-web-terminal-container-v2.0.6-3.tar.gz: package/mdist/controller/kubectl/top.js <==
/*
 * Copyright 2019 IBM Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import flags from './flags';
import { exec } from './exec';
import commandPrefix from '../command-prefix';
import { isUsage, doHelp } from '../../lib/util/help';
import { doGetAsTable } from './get';
const verb = 'top';
/**
 * This is the main handler for `kubectl top`.
 *
 */
const doTop = (command) => function _doTop(args) {
    return __awaiter(this, void 0, void 0, function* () {
        if (isUsage(args)) {
            return doHelp(command, args);
        }
        else {
            // first, we do the raw exec of the given command
            const response = yield exec(args);
            return doGetAsTable(command, args, response, verb);
        }
    });
};
export default (commandTree) => {
    commandTree.listen(`/${commandPrefix}/kubectl/${verb}/node`, doTop('kubectl'), flags);
    commandTree.listen(`/${commandPrefix}/k/${verb}/node`, doTop('k'), flags);
    commandTree.listen(`/${commandPrefix}/kubectl/${verb}/pod`, doTop('kubectl'), flags);
    commandTree.listen(`/${commandPrefix}/k/${verb}/pod`, doTop('k'), flags);
};
//# sourceMappingURL=top.js.map

==> kui-web-terminal-container-v2.3.6-6.tar.gz: package/mdist/controller/kubectl/top.js <==
/*
 * Copyright 2019 The Kubernetes Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import flags from './flags';
import { exec } from './exec';
import { isUsage, doHelp } from '../../lib/util/help';
import { doGetAsTable } from './get';
const verb = 'top';
/**
 * This is the main handler for `kubectl top`.
 *
 */
const doTop = (command) => function _doTop(args) {
    return __awaiter(this, void 0, void 0, function* () {
        if (isUsage(args)) {
            return doHelp(command, args);
        }
        else {
            // first, we do the raw exec of the given command
            const response = yield exec(args);
            return doGetAsTable(command, args, response, verb);
        }
    });
};
export default (commandTree) => {
    commandTree.listen(`/kubectl/${verb}/node`, doTop('kubectl'), flags);
    commandTree.listen(`/k/${verb}/node`, doTop('k'), flags);
    commandTree.listen(`/kubectl/${verb}/pod`, doTop('kubectl'), flags);
    commandTree.listen(`/k/${verb}/pod`, doTop('k'), flags);
};
//# sourceMappingURL=top.js.map
